==> tfds-nightly-4.9.4.dev202405280044.tar.gz: tfds-nightly-4.9.4.dev202405280044/tensorflow_datasets/core/utils/__init__.py <==
# coding=utf-8
# Copyright 2024 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Util import."""

from tensorflow_datasets.core.units import Size
from tensorflow_datasets.core.utils import docs
from tensorflow_datasets.core.utils.gcs_utils import gcs_path
from tensorflow_datasets.core.utils.image_utils import apply_colormap
from tensorflow_datasets.core.utils.image_utils import create_thumbnail
from tensorflow_datasets.core.utils.image_utils import decode_image
from tensorflow_datasets.core.utils.image_utils import ffmpeg_run
from tensorflow_datasets.core.utils.image_utils import get_colormap
from tensorflow_datasets.core.utils.image_utils import jpeg_cmyk_to_rgb
from tensorflow_datasets.core.utils.image_utils import PilImage
from tensorflow_datasets.core.utils.image_utils import png_to_jpeg
from tensorflow_datasets.core.utils.image_utils import THUMBNAIL_SIZE
from tensorflow_datasets.core.utils.py_utils import add_sys_path
from tensorflow_datasets.core.utils.py_utils import atomic_write
from tensorflow_datasets.core.utils.py_utils import basename_from_url
from tensorflow_datasets.core.utils.py_utils import build_synchronize_decorator
from tensorflow_datasets.core.utils.py_utils import classproperty
from tensorflow_datasets.core.utils.py_utils import dedent
from tensorflow_datasets.core.utils.py_utils import disable_logging
from tensorflow_datasets.core.utils.py_utils import flatten_nest_dict
from tensorflow_datasets.core.utils.py_utils import flatten_with_path
from tensorflow_datasets.core.utils.py_utils import get_base64
from tensorflow_datasets.core.utils.py_utils import get_class_path
from tensorflow_datasets.core.utils.py_utils import get_class_url
from tensorflow_datasets.core.utils.py_utils import has_sufficient_disk_space
from tensorflow_datasets.core.utils.py_utils import incomplete_dir
from tensorflow_datasets.core.utils.py_utils import incomplete_file
from tensorflow_datasets.core.utils.py_utils import indent
from tensorflow_datasets.core.utils.py_utils import is_incomplete_file
from tensorflow_datasets.core.utils.py_utils import is_notebook
from tensorflow_datasets.core.utils.py_utils import list_info_files
from tensorflow_datasets.core.utils.py_utils import map_nested
from tensorflow_datasets.core.utils.py_utils import memoize
from tensorflow_datasets.core.utils.py_utils import NonMutableDict
from tensorflow_datasets.core.utils.py_utils import nullcontext
from tensorflow_datasets.core.utils.py_utils import pack_as_nest_dict
from tensorflow_datasets.core.utils.py_utils import print_notebook
from tensorflow_datasets.core.utils.py_utils import reraise
from tensorflow_datasets.core.utils.py_utils import rgetattr
from tensorflow_datasets.core.utils.py_utils import temporary_assignment
from tensorflow_datasets.core.utils.py_utils import Tree
from tensorflow_datasets.core.utils.py_utils import try_reraise
from tensorflow_datasets.core.utils.py_utils import warning
from tensorflow_datasets.core.utils.py_utils import zip_dict
from tensorflow_datasets.core.utils.py_utils import zip_nested
from tensorflow_datasets.core.utils.resource_utils import tfds_path
from tensorflow_datasets.core.utils.resource_utils import tfds_write_path
from tensorflow_datasets.core.utils.resource_utils import to_write_path
from tensorflow_datasets.core.utils.tf_utils import assert_shape_match
from tensorflow_datasets.core.utils.tf_utils import assert_tf_shape_match
from tensorflow_datasets.core.utils.tf_utils import convert_to_shape
from tensorflow_datasets.core.utils.tf_utils import GraphRun
from tensorflow_datasets.core.utils.tf_utils import maybe_with_graph
from tensorflow_datasets.core.utils.tf_utils import merge_shape
from tensorflow_datasets.core.utils.tf_utils import nogpu_session
from tensorflow_datasets.core.utils.tf_utils import normalize_shape
from tensorflow_datasets.core.utils.tf_utils import raw_nogpu_session
from tensorflow_datasets.core.utils.tf_utils import RunArgs
from tensorflow_datasets.core.utils.tf_utils import shapes_are_compatible
from tensorflow_datasets.core.utils.tf_utils import TFGraphRunner
from tensorflow_datasets.core.utils.tqdm_utils import async_tqdm
from tensorflow_datasets.core.utils.tqdm_utils import disable_progress_bar
from tensorflow_datasets.core.utils.tqdm_utils import display_progress_bar
from tensorflow_datasets.core.utils.tqdm_utils import EmptyTqdm
from tensorflow_datasets.core.utils.tqdm_utils import enable_progress_bar
from tensorflow_datasets.core.utils.tqdm_utils import tqdm
from tensorflow_datasets.core.utils.tqdm_utils import TqdmStream
from tensorflow_datasets.core.utils.type_utils import *
from tensorflow_datasets.core.utils.version import Experiment
from tensorflow_datasets.core.utils.version import Version

==> tfds-nightly-4.9.6.dev202407170044.tar.gz: tfds-nightly-4.9.6.dev202407170044/tensorflow_datasets/core/utils/__init__.py <==
# coding=utf-8
# Copyright 2024 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Util import."""

from tensorflow_datasets.core.units import Size
from tensorflow_datasets.core.utils import docs
from tensorflow_datasets.core.utils.file_utils import incomplete_dir
from tensorflow_datasets.core.utils.gcs_utils import gcs_path
from tensorflow_datasets.core.utils.image_utils import apply_colormap
from tensorflow_datasets.core.utils.image_utils import create_thumbnail
from tensorflow_datasets.core.utils.image_utils import decode_image
from tensorflow_datasets.core.utils.image_utils import ffmpeg_run
from tensorflow_datasets.core.utils.image_utils import get_colormap
from tensorflow_datasets.core.utils.image_utils import jpeg_cmyk_to_rgb
from tensorflow_datasets.core.utils.image_utils import PilImage
from tensorflow_datasets.core.utils.image_utils import png_to_jpeg
from tensorflow_datasets.core.utils.image_utils import THUMBNAIL_SIZE
from tensorflow_datasets.core.utils.py_utils import add_sys_path
from tensorflow_datasets.core.utils.py_utils import atomic_write
from tensorflow_datasets.core.utils.py_utils import basename_from_url
from tensorflow_datasets.core.utils.py_utils import build_synchronize_decorator
from tensorflow_datasets.core.utils.py_utils import classproperty
from tensorflow_datasets.core.utils.py_utils import dedent
from tensorflow_datasets.core.utils.py_utils import disable_logging
from tensorflow_datasets.core.utils.py_utils import flatten_nest_dict
from tensorflow_datasets.core.utils.py_utils import flatten_with_path
from tensorflow_datasets.core.utils.py_utils import get_base64
from tensorflow_datasets.core.utils.py_utils import get_class_path
from tensorflow_datasets.core.utils.py_utils import get_class_url
from tensorflow_datasets.core.utils.py_utils import has_sufficient_disk_space
from tensorflow_datasets.core.utils.py_utils import incomplete_file
from tensorflow_datasets.core.utils.py_utils import indent
from tensorflow_datasets.core.utils.py_utils import is_incomplete_file
from tensorflow_datasets.core.utils.py_utils import is_notebook
from tensorflow_datasets.core.utils.py_utils import list_info_files
from tensorflow_datasets.core.utils.py_utils import map_nested
from tensorflow_datasets.core.utils.py_utils import memoize
from tensorflow_datasets.core.utils.py_utils import NonMutableDict
from tensorflow_datasets.core.utils.py_utils import nullcontext
from tensorflow_datasets.core.utils.py_utils import pack_as_nest_dict
from tensorflow_datasets.core.utils.py_utils import print_notebook
from tensorflow_datasets.core.utils.py_utils import reraise
from tensorflow_datasets.core.utils.py_utils import rgetattr
from tensorflow_datasets.core.utils.py_utils import temporary_assignment
from tensorflow_datasets.core.utils.py_utils import Tree
from tensorflow_datasets.core.utils.py_utils import try_reraise
from tensorflow_datasets.core.utils.py_utils import warning
from tensorflow_datasets.core.utils.py_utils import zip_dict
from tensorflow_datasets.core.utils.py_utils import zip_nested
from tensorflow_datasets.core.utils.resource_utils import tfds_path
from tensorflow_datasets.core.utils.resource_utils import tfds_write_path
from tensorflow_datasets.core.utils.resource_utils import to_write_path
from tensorflow_datasets.core.utils.tf_utils import assert_shape_match
from tensorflow_datasets.core.utils.tf_utils import assert_tf_shape_match
from tensorflow_datasets.core.utils.tf_utils import convert_to_shape
from tensorflow_datasets.core.utils.tf_utils import GraphRun
from tensorflow_datasets.core.utils.tf_utils import maybe_with_graph
from tensorflow_datasets.core.utils.tf_utils import merge_shape
from tensorflow_datasets.core.utils.tf_utils import nogpu_session
from tensorflow_datasets.core.utils.tf_utils import normalize_shape
from tensorflow_datasets.core.utils.tf_utils import raw_nogpu_session
from tensorflow_datasets.core.utils.tf_utils import RunArgs
from tensorflow_datasets.core.utils.tf_utils import shapes_are_compatible
from tensorflow_datasets.core.utils.tf_utils import TFGraphRunner
from tensorflow_datasets.core.utils.tqdm_utils import async_tqdm
from tensorflow_datasets.core.utils.tqdm_utils import disable_progress_bar
from tensorflow_datasets.core.utils.tqdm_utils import display_progress_bar
from tensorflow_datasets.core.utils.tqdm_utils import EmptyTqdm
from tensorflow_datasets.core.utils.tqdm_utils import enable_progress_bar
from tensorflow_datasets.core.utils.tqdm_utils import tqdm
from tensorflow_datasets.core.utils.tqdm_utils import TqdmStream
from tensorflow_datasets.core.utils.type_utils import *
from tensorflow_datasets.core.utils.version import BlockedVersions
from tensorflow_datasets.core.utils.version import DatasetVariantBlockedError
from tensorflow_datasets.core.utils.version import Experiment
from tensorflow_datasets.core.utils.version import Version
